(* ::Package:: *)

(* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Model file: WIMP-like toy model

s-wave constant annihilation cross section and effective scattering rate

Model parameters:

    mDM - DM mass
    gDM - # of internal degrees of freedom of DM
    sv0 - annihilation cross section times velocity (sigma*v_lab)
    xkd - value of x for which: momentum transfer rate = Hubble rate

Version: 12-10-2020
Contact: Andrzej Hryczuk (NCBJ)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% *)

(*********************** specification of the model ***************************)

Print["----------------- Model: WIMP-like toy model ----------------"];
cardinfo:={"-------- card: "<>parameters<>" mDM="<>ToString[N[mDM]]<>
          "  gDM="<>ToString[gDM]<>"  sv0="<>ToString[N[sv0],CForm]<>
          "  xkd="<>ToString[N[xkd]]<>"--------"};

(*************************** annihilation cross section ***********************)

sv[s_]          :=  sv0;
resonance       :=   {};
threshold       :=   {};

(*************************  momentum transfer rate  ***************************)

scatttype        =   "gamma(x)";
gam[x_]         :=  (xkd/x)^4 H[mDM/x]; (* DM kinetically decouples at around x=xkd *)
